DjangoPublish
=============

# Features

1. Dynamic template directory that allows changing themes on the fly.
2. Dynamic wesite creation just by dorpping a view folder inside your predefined django project/app directory.